@@ -2,7 +2,7 @@
 #
 # 
 #    Ejecter - Safely, easily remove external peripherals
-#    Copyright 2008-2009, Federico Pelloni <federico.pelloni@gmail.com>
+#    Copyright 2008-2011, Federico Pelloni <federico.pelloni@gmail.com>
 # 
 #    
 #    This file is part of Ejecter.
@@ -25,5 +25,5 @@
 waf=./waf
 target=${HOME}/Progetti/ejecter/test
 
-$waf configure --prefix=$target --debug && $waf $1 && $waf $1 install && $target/bin/ejecter
+$waf configure --prefix=$target --debug && $waf $1 && $waf $1 install && $target/bin/ejecter $2
 
